@@ -13,10 +13,12 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_kinesisanalytics.literals import (
+    ApplicationStatus,
+    InputStartingPosition,
+    RecordFormatType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -90,9 +92,7 @@ _RequiredApplicationDetailTypeDef = TypedDict(
     {
         "ApplicationName": str,
         "ApplicationARN": str,
-        "ApplicationStatus": Literal[
-            "DELETING", "STARTING", "STOPPING", "READY", "RUNNING", "UPDATING"
-        ],
+        "ApplicationStatus": ApplicationStatus,
         "ApplicationVersionId": int,
     },
 )
@@ -120,13 +120,7 @@ class ApplicationDetailTypeDef(
 
 ApplicationSummaryTypeDef = TypedDict(
     "ApplicationSummaryTypeDef",
-    {
-        "ApplicationName": str,
-        "ApplicationARN": str,
-        "ApplicationStatus": Literal[
-            "DELETING", "STARTING", "STOPPING", "READY", "RUNNING", "UPDATING"
-        ],
-    },
+    {"ApplicationName": str, "ApplicationARN": str, "ApplicationStatus": ApplicationStatus},
 )
 
 CSVMappingParametersTypeDef = TypedDict(
@@ -167,7 +161,7 @@ class CloudWatchLoggingOptionUpdateTypeDef(
 
 
 DestinationSchemaTypeDef = TypedDict(
-    "DestinationSchemaTypeDef", {"RecordFormatType": Literal["JSON", "CSV"]}
+    "DestinationSchemaTypeDef", {"RecordFormatType": RecordFormatType}
 )
 
 InputDescriptionTypeDef = TypedDict(
@@ -233,7 +227,7 @@ InputSchemaUpdateTypeDef = TypedDict(
 
 InputStartingPositionConfigurationTypeDef = TypedDict(
     "InputStartingPositionConfigurationTypeDef",
-    {"InputStartingPosition": Literal["NOW", "TRIM_HORIZON", "LAST_STOPPED_POINT"]},
+    {"InputStartingPosition": InputStartingPosition},
     total=False,
 )
 
@@ -407,7 +401,7 @@ class RecordColumnTypeDef(_RequiredRecordColumnTypeDef, _OptionalRecordColumnTyp
 
 
 _RequiredRecordFormatTypeDef = TypedDict(
-    "_RequiredRecordFormatTypeDef", {"RecordFormatType": Literal["JSON", "CSV"]}
+    "_RequiredRecordFormatTypeDef", {"RecordFormatType": RecordFormatType}
 )
 _OptionalRecordFormatTypeDef = TypedDict(
     "_OptionalRecordFormatTypeDef", {"MappingParameters": "MappingParametersTypeDef"}, total=False
